<?php
class Event{

private $table;
public $statusCode = array('approved'=>'A','pending'=>'P');

public $id;
public $venueId;
public $venueName;
public $venueAddress;
public $userId;
public $name;
public $description;
public $price;
public $image;
public $url;
public $status;
public $dateStart;
public $dateEnd;
public $error = array();
//private $debug = true;

function __construct(){
	global $wpdb;
	$this->table = $wpdb->prefix."eom_events";
}

//add data to user object, via array(name, description, price, imageUrl, url, status)
public function put($data){
	$this->id = (int) $this->_validate($data['id'], false, 1, 5, 'number');
	$this->venueId = (int) $this->_validate($data['venueId'], false, 1, 5, 'number');
	$this->status=$data['status'];
	$this->name = $this->_validate($data['name'], true, 1, 150, 'text');
	$this->description = $this->_validate($data['description'], true, 1, 1000, 'text');
	$this->price = $this->_validate($data['price'], false, 1, 5, 'number');
	$this->image = $this->_validate($data['image'], false, 1, 200, 'text');
	$this->url = $this->_validate($data['url'], false, 1, 200, 'text');
	if(!$this->name){$this->error[] = 'Invalid Event Name';}
	if(!$this->description){$this->error[] = 'Invalid Event Description';}
}

//add to database. Return 2 if update, 1 if insert, false on fail
public function save(){
	global $wpdb;
	$data=array('name'=>$this->name, 'description'=>$this->description, 'venue_id'=>$this->venueId, 'user_id'=>$this->userId, 'status'=>$this->status, 'flyer'=>esc_url_raw($this->image), 'price'=>$this->price, 'website'=>esc_url_raw($this->url));
	$datatype=array( '%s', '%s', '%d', '%d', '%s','%s','%f','%s' );
	if($this->id){
		//update
		$wpdb->update( $this->table, $data, array('id'=>$this->id), $datatype, '%d');
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		return 2;
	}else{
		//insert
		$wpdb->insert($this->table, $data, $datatype );
		$this->id=$wpdb->insert_id;
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		return 1;
	}
}

//retrieve from database
public function getAll($var=array(
'when'=>NULL,'status'=>NULL,'order'=>NULL,'orderDirection'=>NULL,'limit'=>NULL,'count'=>NULL,'venue'=>NULL)){
	global $wpdb;
	if($var['order']){$orderSQL='ORDER BY '.$var['order'];}else{$orderSQL='';}
	if($var['orderDirection']){$orderSQL.=' '.$var['orderDirection'];}
	if($var['limit']){$limitSQL="LIMIT ".$var['limit']." ";}else{$limitSQL='';}
	if($var['when']=='upcoming'){$whereSQL=' WHERE '.EOMDATES.'.end > NOW()';}
	elseif($var['when']=='archive'){$whereSQL=' WHERE '.EOMDATES.'.end < NOW()';}
	else{$whereSQL='';}
	if($var['status']){
		if($var['when']){$whereSQL.=' AND ';}else{$whereSQL.=' WHERE ';}
		$whereSQL.=$this->table.".status = '".$var['status']."' ";
	}
	if($var['venue']){//get all events at select venue
		$whereSQL.=' AND '.$this->table.'.venue_id = '.$var['venue'].' ';
	}
	if($var['count']){$select="COUNT(*)";}else{
	$select=$this->table.".id AS id,
	".$this->table.".name AS name,
	".$this->table.".description AS description,
	".$this->table.".flyer AS image,
	".$this->table.".status AS status, 
	".EOMDATES.".start AS dateStart, 
	".EOMDATES.".end AS dateEnd, 
	".EOMUSERS.".email AS userEmail,
	".EOMVENUES.".name AS venueName, 
	".EOMVENUES.".id AS venueId"; 
	}
	$sql=$wpdb->prepare(
	"SELECT ".$select." FROM ".$this->table."
	LEFT JOIN ".EOMVENUES." ON ".$this->table.".venue_id=".EOMVENUES.".id 
	LEFT JOIN ".EOMUSERS." ON ".$this->table.".user_id=".EOMUSERS.".id 
	LEFT JOIN ".EOMDATES." ON ".$this->table.".id=".EOMDATES.".event_id
	".$whereSQL." ".$orderSQL." ".$limitSQL.";");
	if($var['count']){$results=$wpdb->get_var($sql);}else{$results=$wpdb->get_results($sql, ARRAY_A);}
	if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	return $results;
}

public function get(){
	global $wpdb;
	$sql=$wpdb->prepare(
		"SELECT ".$this->table.".id AS id,
		".$this->table.".name AS name,
		".$this->table.".description AS description,
		".$this->table.".price AS price,
		".$this->table.".flyer AS image,
		".$this->table.".website AS url,
		".$this->table.".status AS status, 
		".EOMDATES.".start AS dateStart, 
		".EOMDATES.".end AS dateEnd, 
		".EOMVENUES.".id AS venueId, 
		".EOMVENUES.".name AS venueName,
		".EOMVENUES.".fullAddress AS venueAddress,
		".EOMUSERS.".id AS userId FROM ".$this->table."
		LEFT JOIN ".EOMVENUES." ON ".$this->table.".venue_id=".EOMVENUES.".id 
		LEFT JOIN ".EOMUSERS." ON ".$this->table.".user_id=".EOMUSERS.".id 
		LEFT JOIN ".EOMDATES." ON ".$this->table.".id=".EOMDATES.".event_id
		WHERE ".$this->table.".id = %d",$this->id);
	$event=$wpdb->get_row($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($event){
		$this->name = $event['name'];
		$this->description = $event['description'];
		$this->price = $event['price'];
		$this->image = $event['image'];
		$this->url = $event['url'];
		$this->status = $event['status'];
		$this->venueId = (int) $event['venueId'];
		$this->venueName = $event['venueName'];
		$this->venueAddress = $event['venueAddress'];
		$this->userId = (int) $event['userId'];
		$this->dateStart = $event['dateStart'];
		$this->dateEnd = $event['dateEnd'];
		return true;
	}else{return false;}
}

//delete event
public function delete(){
	global $wpdb;
	if($wpdb->query( $wpdb->prepare("DELETE FROM ".$this->table." WHERE id = %d", $this->id))){
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		$wpdb->query( $wpdb->prepare("DELETE FROM ".EOMDATES." WHERE event_id = %d", $this->id));
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		return true;
	}
	return false;
}

//update event status
public function statusSave(){
	global $wpdb;
	if($this->id && $this->status){
		$data=array('status'=>$this->status);
		$datatype=array('%s');
		$wpdb->update( $this->table, $data, array('id'=>$this->id), $datatype, '%d');
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		return true;
	}
	return false;
}

//validation script
protected function _validate($data, $isReq, $min, $max, $type){
	$data=stripslashes(trim($data));
	if($data==''){if($isReq==true){return false;}else{return '';}}
	if( (strlen($data) > $max) or (strlen($data) < $min) ){return false;}
	if($type=='text'){$data=strip_tags($data);}
	if($type=='number'){if(!is_numeric($data)){return false;}}
	return $data;
}


}//END Event
?>