<?php

class Venue{

private $apiKey;
private $table;
//private $debug = true;

public $id;
public $name;
public $address;
public $street;
public $city;
public $state;
public $country;
public $lat;
public $lon;
public $error = array();

function __construct(){
	global $wpdb;
	$this->table = $wpdb->prefix."eom_venues";
	$this->apiKey = get_option('eom_google_api');
}

//put venue name and address into object. checks validity of address with google and existence in db
public function put($data){
	$this->id = $this->_validate($data['id'], true, 1, 10, 'number');
	$this->name = $this->_validate($data['name'], true, 1, 100, 'text');
	$address = $this->_validate($data['address'], true, 1, 200, 'text');
	if($address){
		$place = $this->lookup($address);
		if(count($place)==1){
			$existsResult = $this->exists($place[0]['fullAddress']);
			if(($existsResult)  && ($existsResult != $this->id)){
				//does address exist AND does it not equal this venue id
				$this->error[]='A venue with this address already exists.';return false;
			}
			$this->street = $place[0]['street'];
			$this->city = $place[0]['city'];
			$this->state = $place[0]['state'];
			$this->country = $place[0]['country']; 
			$this->address = $place[0]['fullAddress'];
			$this->lat = $place[0]['lat'];
			$this->lon = $place[0]['lon'];
		}else{//ambiguous invalid address (more than one or zero lookup results)
			$this->error[]='This address is invalid.';return false;
		}
	}
}


//look up address, return all good results that have an 8 accuracy (street address)
private function lookup($address){
	$response = $this->performRequest($address, 'xml');
	$xml      = new SimpleXMLElement($response);
	$status   = (int) $xml->Response->Status->code;
	switch ($status) {
	//200 = valid result
	case 200:
	$total=0;
	foreach ($xml->Response->Placemark as $placemark){
		list($lon, $lat, $trash)=explode(',',$placemark->Point->coordinates);
		$accuracy = (int) $placemark->AddressDetails['Accuracy'];
		//$country = (string) $placemark->AddressDetails->Country;
		$country = (string) $placemark->AddressDetails->Country->CountryNameCode;
		$street = (string) $placemark->AddressDetails->Country->AdministrativeArea->Locality->Thoroughfare->ThoroughfareName;
		$city = (string) $placemark->AddressDetails->Country->AdministrativeArea->Locality->LocalityName;
		if(!$city){$city = (string) $placemark->AddressDetails->Country->AdministrativeArea->SubAdministrativeArea->Locality->LocalityName; }
		$state = (string) $placemark->AddressDetails->Country->AdministrativeArea->AdministrativeAreaName;
		$zip = (int) $placemark->AddressDetails->Country->AdministrativeArea->Locality->PostalCode->PostalCodeNumber;
		$fullAddress = (string) $placemark->address;
		
		if($accuracy>=7){
		$placemarks[$total]['lat']=$lat;
		$placemarks[$total]['lon']=$lon;
		$placemarks[$total]['street']=$street;
		$placemarks[$total]['city']=$city;
		$placemarks[$total]['state']=$state;
		$placemarks[$total]['country']=$country;
		$placemarks[$total]['zip']=$zip;
		$placemarks[$total]['fullAddress']=$fullAddress;
		}
		$total++;
	}
	return $placemarks;
	
	default:
	return false;
	}
}

//run lookup, used internally
private function performRequest($search, $output='xml'){
	$url = sprintf('http://maps.google.com/maps/geo?q=%s&output=%s&key=%s&oe=utf-8', urlencode($search), $output, $this->apiKey);
	$ch = curl_init($url);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	$response = curl_exec($ch);
	curl_close($ch);
	return $response;
}


//add to database. Return 2 if update, 1 if insert, false on fail
public function save(){
	global $wpdb;
	$data=array('name'=>$this->name, 'street'=>$this->street,'city'=>$this->city, 'fullAddress'=>$this->address, 'lat'=>$this->lat, 'lon'=>$this->lon);
	$datatype=array( '%s','%s','%s','%s','%F','%F' );
	if($this->id){
		//update
		$wpdb->update( $this->table, $data, array('id'=>$this->id), $datatype, '%d');
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		return 2;
	}else{
		//insert
		$wpdb->insert($this->table, $data, $datatype);
		$this->id = (int) $wpdb->insert_id;
		if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
		return 1;
	}
	return false;
}


public function getAll($var=array('limit'=>NULL,'count'=>NULL,'order'=>NULL)){
	global $wpdb;
	if($var['order']){$orderSQL='ORDER BY '.$var['order'];}else{$orderSQL='';}
	if($var['limit']){$limitSQL=" LIMIT ".$var['limit']." ";}else{$limitSQL='';}
	if($var['count']){$select="COUNT(*)";}else{$select="*";}
	$sql=$wpdb->prepare("SELECT ".$select." FROM ".$this->table." ".$orderSQL." ".$limitSQL);
	//if count, use get_var
	if($var['count']){$results=$wpdb->get_var($sql);}else{
		$results=$wpdb->get_results($sql, ARRAY_A);
	}
	if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	return $results;
}

//populate object based on address
public function get($address){
	global $wpdb;
	$sql=$wpdb->prepare("SELECT * FROM ".$this->table." WHERE fullAddress = %s", $address);
	$venue=$wpdb->get_row($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($venue){
		$this->id = (int) $venue['id'];
		$this->name = $venue['name'];
		$this->address = $venue['fullAddress'];
	}else{return false;}
}

//populate object based on id
public function getById(){
	global $wpdb;
	$sql=$wpdb->prepare("SELECT * FROM ".$this->table." WHERE id = %d;",$this->id);
	$venue=$wpdb->get_row($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.'->'.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($venue){
		$this->name = $venue['name'];
		$this->address = $venue['fullAddress'];
		$this->lat = $venue['lat'];
		$this->lon = $venue['lon'];
		return true;
	}else{return false;}
}

//delete venue
public function delete(){
	global $wpdb;
	if($wpdb->query( $wpdb->prepare("DELETE FROM ".$this->table." WHERE id = %d", $this->id))){
	if($this->debug){print_r(__CLASS__.' -> '.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	return true;
	}
	return false;
}

//check address in db. return id if exists, false on failure
public function exists($address){
	global $wpdb;
	$sql=$wpdb->prepare("SELECT id FROM ".$this->table." WHERE fullAddress = %s", $address);
	$venue=$wpdb->get_row($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.'->'.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($venue){
		return $venue['id'];
	}else{return false;}
}

//venue in use by events. return array of event ids if in use, false if not.
public function inUse(){
	global $wpdb;
	$sql=$wpdb->prepare("SELECT id, name FROM ".EOMEVENTS." WHERE venue_id = %d", $this->id);
	$events=$wpdb->get_results($sql, ARRAY_A);
	if($this->debug){print_r(__CLASS__.'->'.__FUNCTION__.' at '.__LINE__.'<pre>'.$wpdb->last_query.'</pre>');}
	if($events){return $events;}else{return false;}
}

//validation script
protected function _validate($data, $isReq, $min, $max, $type){
	$data=stripslashes(trim($data));
	if($data==''){if($isReq==true){return false;}else{return '';}}
	if( (strlen($data) > $max) or (strlen($data) < $min) ){return false;}
	if($type=='text'){$data=strip_tags($data);}
	return $data;
}

//return field select of approved venues selected with $id
public function fieldVenue($id=NULL){
	$venues=$this->getAll(array('order'=>'name'));
    $retSelect='<select name="venueId">';
	if (!$id){$retSelect.='<option value="" >Select Venue...</option>';}
	foreach ($venues as $key => $value) {
    	if ($id == $value['id']) {
		$retSelect.='<option value="'.$value['id'].'" selected="selected">'.stripslashes($value['name']).'</option>';
        }else{$retSelect.='<option value="'.$value['id'].'">'.$value['name'].'</option>';}
    }
	$retSelect.='</select>';
	return $retSelect;
}

}//END User
?>